## ----include = FALSE----------------------------------------------------------
BiocStyle::markdown()
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## -----------------------------------------------------------------------------
table <- data.frame(Nomenclature=c("a","b","c","d"), 
                    `Distance Metric`=rep(c("Correlation", "Gower"), each=2), 
                    `Clustering Method`=c("K-means", "Hierarchical Clustering", 
                                          "K-medoids", "Hierarchical-Clustering"))
knitr::kable(table, align = c("l", "l", "l"))

## ----installation, eval=FALSE-------------------------------------------------
#  if (!require("devtools", quietly = TRUE))
#      install.packages("devtools")
#  devtools::install_github("TranslationalBioinformaticsUnit/ClustAll")

## ----load---------------------------------------------------------------------
library(ClustAll)

## -----------------------------------------------------------------------------
# load example data
data("BreastCancerWisconsin", package = "ClustAll") 
# remove patients IDs (non-informative)
data_use <- subset(wdbc, select=-ID)
# check the presence of missing values
sum(is.na(data_use))

## -----------------------------------------------------------------------------
obj_noNA <- createClustAll(data = data_use, nImputation = NULL, 
                           dataImputed = NULL, colValidation = "Diagnosis")

## ----results=FALSE------------------------------------------------------------
obj_noNA1 <- runClustAll(Object = obj_noNA, threads = 2, simplify = FALSE)

## -----------------------------------------------------------------------------
obj_noNA1

## ----results=FALSE, warning=FALSE---------------------------------------------
plotJACCARD(Object = obj_noNA1, stratification_similarity = 0.88)

## -----------------------------------------------------------------------------
resStratification(Object = obj_noNA1, population = 0.05, 
                  stratification_similarity = 0.88, all = FALSE)

## -----------------------------------------------------------------------------
plotSANKEY(Object = obj_noNA1, clusters = c("cuts_c_3","cuts_a_9"), 
           validationData = FALSE)

plotSANKEY(Object = obj_noNA1, clusters = c("cuts_a_9"), 
           validationData = TRUE)

## -----------------------------------------------------------------------------
df <- cluster2data(Object = obj_noNA1,
                   stratificationName = c("cuts_c_3","cuts_a_9","cuts_b_9"))

## -----------------------------------------------------------------------------
# STRATIFICATION 1
validateStratification(obj_noNA1, "cuts_a_9")
# STRATIFICATION 2
validateStratification(obj_noNA1, "cuts_b_13")
# STRATIFICATION 3
validateStratification(obj_noNA1, "cuts_b_9")

## -----------------------------------------------------------------------------
sessionInfo()

